@@ -118,6 +118,11 @@ KEYWORD is :val, :sql, or :data.
 NAME is binding name as string.
 VALUE is binding value as string (Elisp literal representation).
 
+If a binding with NAME already exists in KEYWORD parameter,
+prompt to replace it.  On confirmation, replace the value in
+place, preserving the parameter's position in the form.  On
+refusal, signal `user-error'.
+
 If KEYWORD parameter exists, append (NAME . VALUE) to its alist.
 If KEYWORD parameter does not exist, insert it before the closing
 parenthesis of the form.
@@ -129,11 +134,30 @@ For :data, VALUE is an Elisp data expression.
 Return position after inserted text.
 
 Caller is responsible for proper VALUE formatting.
-Uses `duckdb-query-edit--find-param' for parameter location."
-  (let ((param (duckdb-query-edit--find-param form-beg form-end keyword)))
-    (if param
-        (duckdb-query-edit--append-to-param param name value)
-      (duckdb-query-edit--insert-new-param form-end keyword name value))))
+Uses `duckdb-query-edit--find-param' for parameter location.
+Uses `duckdb-query-edit--replace-binding-value' for in-place replacement."
+  ;; NOTE 2025-07-02: Duplicate check is inlined here.  Extract into
+  ;; utility function if needed elsewhere in the future.
+  (let ((replaced nil)
+        (existing-param (duckdb-query-edit--find-param
+                         form-beg form-end keyword)))
+    (when (and existing-param
+               (memq (intern name)
+                     (duckdb-query--extract-binding-names
+                      (plist-get existing-param :val-beg)
+                      (plist-get existing-param :val-end))))
+      (let ((type-str (substring (symbol-name keyword) 1)))
+        (unless (y-or-n-p (format "@%s:%s already bound; replace? "
+                                  type-str name))
+          (user-error "Binding @%s:%s already exists" type-str name))
+        (duckdb-query-edit--replace-binding-value
+         form-beg form-end keyword name value)
+        (setq replaced t)))
+    (unless replaced
+      (let ((param (duckdb-query-edit--find-param form-beg form-end keyword)))
+        (if param
+            (duckdb-query-edit--append-to-param param name value)
+          (duckdb-query-edit--insert-new-param form-end keyword name value))))))
 
 (defun duckdb-query-edit--find-last-binding-end (val-beg val-end)
   "Find position after last binding entry in alist between VAL-BEG and VAL-END.
@@ -408,8 +432,9 @@ branches."
 TEXT is the raw Elisp literal as extracted from the buffer.
 
 For :sql, strip surrounding double quotes to get raw SQL.
-For :val, strip surrounding double quotes for strings, or
-return numeric text as-is.
+For :val, strip surrounding double quotes for strings and
+re-wrap with SQL single quotes to restore the literal form
+that DuckDB expects.  Numeric text is returned as-is.
 For :data, return as-is.
 
 Return string suitable for insertion into a SQL string.
@@ -417,7 +442,21 @@ Return string suitable for insertion into a SQL string.
 Uses `duckdb-query-edit--strip-elisp-string-quotes' for
 double-quote stripping."
   (pcase ref-type
-    ((or :sql :val) (duckdb-query-edit--strip-elisp-string-quotes text))
+    (:sql (duckdb-query-edit--strip-elisp-string-quotes text))
+    (:val
+     (let ((stripped (duckdb-query-edit--strip-elisp-string-quotes text)))
+       (cond
+        ;; Numeric literal - no quotes needed
+        ((string-match-p "\\`-?[0-9]*\\.?[0-9]+\\'" stripped)
+         stripped)
+        ;; Already has SQL single quotes (defensive)
+        ((and (>= (length stripped) 2)
+              (eq (aref stripped 0) ?')
+              (eq (aref stripped (1- (length stripped))) ?'))
+         stripped)
+        ;; String value - restore SQL single quotes
+        (t
+         (format "'%s'" stripped)))))
     (_ text)))
 
 ;;;; Internal: Remove Binding
@@ -494,14 +533,14 @@ Delete from keyword start to value end, including leading
 whitespace on the same line."
   (let ((key-beg (plist-get param :key-beg))
         (val-end (plist-get param :val-end)))
-    ;; Extend backward to consume leading whitespace and newline
     (save-excursion
       (goto-char key-beg)
       (let ((line-start (line-beginning-position)))
         (skip-chars-backward " \t" line-start)
         (when (eq (char-before) ?\n)
           (setq key-beg (1- (point)))))
-      (delete-region key-beg val-end))))
+      (delete-region key-beg val-end)
+      (syntax-ppss-flush-cache key-beg))))
 
 (defun duckdb-query-edit--remove-entry (target _entries)
   "Remove TARGET entry from parameter alist.
@@ -524,11 +563,77 @@ only the entry text."
         (skip-chars-forward " \t")
         (let ((after-is-eol (or (eolp) (eobp))))
           (if (and before-is-blank after-is-eol)
-              ;; Entry owns the line: delete line including newline
-              (delete-region line-start
-                             (min (1+ (line-end-position)) (point-max)))
-            ;; Entry shares a line: delete just the entry
-            (delete-region entry-beg entry-end)))))))
+              (let ((del-beg line-start)
+                    (del-end (min (1+ (line-end-position)) (point-max))))
+                (delete-region del-beg del-end)
+                (syntax-ppss-flush-cache del-beg))
+            (delete-region entry-beg entry-end)
+            (syntax-ppss-flush-cache entry-beg)))))))
+
+;;;; Internal: Replace binding
+(defun duckdb-query-edit--replace-binding-value (form-beg form-end keyword name value)
+  "Replace value of binding NAME in KEYWORD parameter with VALUE.
+
+FORM-BEG and FORM-END delimit the `duckdb-query' form.
+KEYWORD is :val, :sql, or :data.
+NAME is binding name as string.
+VALUE is new Elisp literal string.
+
+Navigate to the cons cell (NAME . OLD-VALUE) and replace OLD-VALUE
+with VALUE, preserving the binding's position in the alist.
+
+Return non-nil if replacement succeeded, nil if binding not found.
+
+Uses `duckdb-query-edit--find-param' for parameter location.
+Called by `duckdb-query-edit--insert-binding' for duplicate replacement."
+  (let ((param (duckdb-query-edit--find-param form-beg form-end keyword)))
+    (when param
+      (save-excursion
+        (goto-char (plist-get param :val-beg))
+        ;; Skip quote/backquote
+        (when (memq (char-after) '(?' ?`))
+          (forward-char 1))
+        (when (eq (char-after) ?\()
+          (let ((list-end (save-excursion
+                            (when (duckdb-query--forward-sexp-safe)
+                              (1- (point))))))
+            (when list-end
+              (forward-char 1)
+              (catch 'replaced
+                (while (< (point) list-end)
+                  (duckdb-query--skip-whitespace-and-comments)
+                  ;; Skip unquote markers
+                  (when (eq (char-after) ?,)
+                    (forward-char 1)
+                    (when (eq (char-after) ?@)
+                      (forward-char 1)))
+                  (duckdb-query--skip-whitespace-and-comments)
+                  (when (and (< (point) list-end)
+                             (eq (char-after) ?\())
+                    (let ((entry-start (point)))
+                      (forward-char 1)
+                      (duckdb-query--skip-whitespace-and-comments)
+                      (when (looking-at (concat (regexp-quote name) "\\_>"))
+                        (goto-char (match-end 0))
+                        (duckdb-query--skip-whitespace-and-comments)
+                        (when (eq (char-after) ?\.)
+                          (forward-char 1)
+                          (duckdb-query--skip-whitespace-and-comments)
+                          ;; Now at old value start
+                          (let ((val-start (point)))
+                            (goto-char entry-start)
+                            (duckdb-query--forward-sexp-safe)
+                            ;; Delete old value (between val-start and closing paren)
+                            (let ((entry-end (1- (point))))
+                              (delete-region val-start entry-end)
+                              (goto-char val-start)
+                              (insert value)
+                              (syntax-ppss-flush-cache val-start))
+                            (throw 'replaced t))))
+                      ;; Not this entry, skip it
+                      (goto-char entry-start)
+                      (unless (duckdb-query--forward-sexp-safe)
+                        (forward-char 1)))))))))))))
 
 ;;;; Internal: Reference Count Check
 
@@ -651,6 +756,8 @@ Also see `duckdb-query-edit-extract-to-sql' for pre-typed variant."
              (marker-position beg-marker)
              (marker-position end-marker)
              ref-type name)
+            ;; Flush stale parse cache from buffer modifications
+            (syntax-ppss-flush-cache (marker-position form-beg-marker))
             ;; Re-indent the form IF enabled
             (duckdb-query-edit--indent-form form-beg-marker))
         ;; Clean up markers
@@ -776,6 +883,8 @@ Also see `duckdb-query-edit-remove-binding'."
                    (marker-position form-beg-marker)
                    (marker-position form-end-marker)
                    ref-type ref-name))
+                ;; Flush stale parse cache from buffer modifications
+                (syntax-ppss-flush-cache (marker-position form-beg-marker))
                 ;; Re-indent IF the setting is enabled
                 (duckdb-query-edit--indent-form form-beg-marker))
             (set-marker form-beg-marker nil)
@@ -831,7 +940,8 @@ all orphaned bindings."
                          form-beg form-end ref-type ref-name)
                   (user-error "No binding for %s in %s parameter"
                               ref-name (symbol-name ref-type)))
-
+                ;; Flush stale parse cache from buffer modifications
+                (syntax-ppss-flush-cache (marker-position form-beg-marker))
                 ;; Re-indent IF the setting is enabled
                 (duckdb-query-edit--indent-form form-beg-marker)
                 (message "Removed %s:%s binding"
